<?php

/*
 * Coupon Compatability Setting
 */
if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}
if (!class_exists('RSCouponCompatability')) {

    class RSCouponCompatability {

        public static function init() {

            add_filter('woocommerce_rs_settings_tabs_array', array(__CLASS__, 'reward_system_tab_setting')); // Register a New Tab in a WooCommerce Reward System Settings        

            add_action('woocommerce_rs_settings_tabs_rewardsystem_coupon_compatability_module', array(__CLASS__, 'reward_system_register_admin_settings')); // Call to register the admin settings in the Reward System Submenu with general Settings tab        

            add_action('woocommerce_update_options_rewardsystem_modules_rewardsystem_coupon_compatability_module', array(__CLASS__, 'reward_system_update_settings')); // call the woocommerce_update_options_{slugname} to update the reward system                               

            add_action('admin_init', array(__CLASS__, 'reward_system_default_settings')); // call the init function to update the default settings on page load

            add_action('fp_action_to_reset_module_settings_rewardsystem_coupon_campatability', array(__CLASS__, 'rs_function_to_reset_coupon_campatability_tab'));

            add_action('woocommerce_admin_field_rs_enable_disable_coupon_compatability_module', array(__CLASS__, 'rs_function_to_enable_disable_coupon_campatability_module'));
        }

        /*
         * Function to Define Name of the Tab
         */

        public static function reward_system_tab_setting($setting_tabs) {
            if (!is_array($setting_tabs))
                $setting_tabs = (array) $setting_tabs;
            $setting_tabs['rewardsystem_coupon_compatability'] = __('Coupon Compatibility Module', 'rewardsystem');
            return $setting_tabs;
        }

        /*
         * Function label settings to Member Level Tab
         */

        public static function reward_system_admin_fields() {
            global $woocommerce;

            return apply_filters('woocommerce_rewardsystem_coupon_compatability_settings', array(
                array(
                    'type' => 'rs_modulecheck_start',
                ),
                array(
                    'name' => __('Coupon Compatibility Module', 'rewardsystem'),
                    'type' => 'title',
                    'id' => '_rs_activate_coupon_compatability_module'
                ),
                array(
                    'type' => 'rs_enable_disable_coupon_compatability_module',
                ),
                array('type' => 'sectionend', 'id' => '_rs_activate_coupon_compatability_module'),
                array(
                    'type' => 'rs_modulecheck_end',
                ),
                array(
                    'type' => 'rs_wrapper_start',
                ),
                array(
                    'name' => __('SUMO Coupon Compatibility Settings', 'rewardsystem'),
                    'type' => 'title',
                    'id' => '_rs_coupon_compatability_setting'
                ),
                array(
                    'name' => __('Don\'t allow Earn Points when SUMO Coupon is applied', 'rewardsystem'),
                    'desc' => __(' Don\'t allow Earn Points when SUMO Coupon is applied', 'rewardsystem'),
                    'id' => '_rs_not_allow_earn_points_if_sumo_coupon',
                    'css' => 'min-width:550px;',
                    'type' => 'checkbox',
                    'std' => 'no',
                    'default' => 'no',
                    'newids' => '_rs_not_allow_earn_points_if_sumo_coupon',
                ),
                array(
                    'name' => __('Don\'t allow Redeem when SUMO Coupon is applied', 'rewardsystem'),
                    'desc' => __('Don\'t allow Redeem when SUMO Coupon is applied', 'rewardsystem'),
                    'id' => 'rs_dont_allow_redeem_if_sumo_coupon',
                    'css' => 'min-width:550px;',
                    'type' => 'checkbox',
                    'std' => 'no',
                    'default' => 'no',
                    'newids' => 'rs_dont_allow_redeem_if_sumo_coupon',
                ),
                array('type' => 'sectionend', 'id' => '_rs_coupon_compatability_setting'),
                array(
                    'type' => 'rs_wrapper_end',
                ),
            ));
        }

        /**
         * Registering Custom Field Admin Settings of SUMO Reward Points in woocommerce admin fields funtion
         */
        public static function reward_system_register_admin_settings() {

            woocommerce_admin_fields(RSCouponCompatability::reward_system_admin_fields());
        }

        /**
         * Update the Settings on Save Changes may happen in SUMO Reward Points
         */
        public static function reward_system_update_settings() {
            woocommerce_update_options(RSCouponCompatability::reward_system_admin_fields());
            if (isset($_POST['rs_coupon_compatability_module_checkbox'])) {
                update_option('rs_coupon_campatability_activated', $_POST['rs_coupon_compatability_module_checkbox']);
            } else {
                update_option('rs_coupon_campatability_activated', 'no');
            }
        }

        /**
         * Initialize the Default Settings by looping this function
         */
        public static function reward_system_default_settings() {
            global $woocommerce;
            foreach (RSCouponCompatability::reward_system_admin_fields() as $setting)
                if (isset($setting['newids']) && isset($setting['std'])) {
                    add_option($setting['newids'], $setting['std']);
                }
        }

        public static function rs_function_to_reset_coupon_campatability_tab() {
            $settings = RSCouponCompatability::reward_system_admin_fields();
            RSTabManagement::rs_function_to_reset_setting($settings);
        }

        public static function rs_function_to_enable_disable_coupon_campatability_module() {
            $get_option_value = get_option('rs_coupon_compatability_activated');
            $name_of_checkbox = 'rs_coupon_compatability_module_checkbox';
            RSModulesTab::rs_common_function_to_get_checkbox($get_option_value, $name_of_checkbox);
        }

    }

    RSCouponCompatability::init();
}