<?php

/*
 * Discounts Compatability Setting
 */
if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}
if (!class_exists('RSDiscountsCompatability')) {

    class RSDiscountsCompatability {

        public static function init() {

            add_filter('woocommerce_rs_settings_tabs_array', array(__CLASS__, 'reward_system_tab_setting')); // Register a New Tab in a WooCommerce Reward System Settings        

            add_action('woocommerce_rs_settings_tabs_rewardsystem_discounts_compatability_module', array(__CLASS__, 'reward_system_register_admin_settings')); // Call to register the admin settings in the Reward System Submenu with general Settings tab        

            add_action('woocommerce_update_options_rewardsystem_modules_rewardsystem_discounts_compatability_module', array(__CLASS__, 'reward_system_update_settings')); // call the woocommerce_update_options_{slugname} to update the reward system                               

            add_action('admin_init', array(__CLASS__, 'reward_system_default_settings')); // call the init function to update the default settings on page load

            add_action('fp_action_to_reset_module_settings_rewardsystem_discounts_campatability', array(__CLASS__, 'rs_function_to_reset_discounts_campatability_tab'));

            add_action('woocommerce_admin_field_rs_enable_disable_discounts_compatability_module', array(__CLASS__, 'rs_function_to_enable_disable_discounts_campatability_module'));
        }

        /*
         * Function to Define Name of the Tab
         */

        public static function reward_system_tab_setting($setting_tabs) {
            if (!is_array($setting_tabs))
                $setting_tabs = (array) $setting_tabs;
            $setting_tabs['rewardsystem_discounts_compatability'] = __('Discounts Compatibility Module', 'rewardsystem');
            return $setting_tabs;
        }

        /*
         * Function label settings to Member Level Tab
         */

        public static function reward_system_admin_fields() {
            global $woocommerce;

            return apply_filters('woocommerce_rewardsystem_discounts_compatability_settings', array(
                array(
                    'type' => 'rs_modulecheck_start',
                ),
                array(
                    'name' => __('Discounts Compatibility Module', 'rewardsystem'),
                    'type' => 'title',
                    'id' => '_rs_activate_discounts_compatability_module'
                ),
                array(
                    'type' => 'rs_enable_disable_discounts_compatability_module',
                ),
                array('type' => 'sectionend', 'id' => '_rs_activate_discounts_compatability_module'),
                array(
                    'type' => 'rs_modulecheck_end',
                ),
                array(
                    'type' => 'rs_wrapper_start',
                ),
                array(
                    'name' => __('SUMO Discounts Compatibility Settings', 'rewardsystem'),
                    'type' => 'title',
                    'id' => '_rs_discounts_compatability_setting'
                ),
                array(
                    'name' => __('Don\'t allow Earn Points when SUMO Discount is applied', 'rewardsystem'),
                    'desc' => __('Don\'t allow Earn Points when SUMO Discount is applied', 'rewardsystem'),
                    'id' => '_rs_not_allow_earn_points_if_sumo_discount',
                    'css' => 'min-width:550px;',
                    'type' => 'checkbox',
                    'std' => 'no',
                    'default' => 'no',
                    'newids' => '_rs_not_allow_earn_points_if_sumo_discount',
                ),
                array(
                    'name' => __('Show Redeeming Field', 'rewardsystem'),
                    'id' => 'rs_show_redeeming_field',
                    'std' => '1',
                    'default' => '1',
                    'type' => 'select',
                    'newids' => 'rs_show_redeeming_field',
                    'options' => array(
                        '1' => __('Always', 'rewardsystem'),
                        '2' => __('When Price is not altered through SUMO Discounts Plugin', 'rewardsystem'),
                    ),
                ),
                array(
                    'name' => __('Show/Hide WooCommerce Coupon Field', 'rewardsystem'),
                    'desc' => __('Enable this checkbox to prevent woocommerce coupon usage when discount from SUMO Discount plugin is applied', 'rewardsystem'),
                    'id' => '_rs_show_hide_coupon_if_sumo_discount',
                    'css' => 'min-width:550px;',
                    'type' => 'checkbox',
                    'std' => 'no',
                    'default' => 'no',
                    'newids' => '_rs_show_hide_coupon_if_sumo_discount',
                ),
                array (
                    'name'    => __( 'Message' , 'rewardsystem' ) ,
                    'id'      => 'rs_message_in_cart_and_checkout_for_discount' ,
                    'std'     => 'Since you got the discount, you cant use the WooCommerce Coupon' ,
                    'default' => 'Since you got the discount, you cant use the WooCommerce Coupon' ,
                    'type'    => 'textarea' ,
                    'newids'  => 'rs_message_in_cart_and_checkout_for_discount' ,
                ) ,
                array('type' => 'sectionend', 'id' => '_rs_discounts_compatability_setting'),
                array(
                    'type' => 'rs_wrapper_end',
                ),
            ));
        }

        /**
         * Registering Custom Field Admin Settings of SUMO Reward Points in woocommerce admin fields funtion
         */
        public static function reward_system_register_admin_settings() {

            woocommerce_admin_fields(RSDiscountsCompatability::reward_system_admin_fields());
        }

        /**
         * Update the Settings on Save Changes may happen in SUMO Reward Points
         */
        public static function reward_system_update_settings() {
            woocommerce_update_options(RSDiscountsCompatability::reward_system_admin_fields());
            if (isset($_POST['rs_discounts_compatability_module_checkbox'])) {
                update_option('rs_discounts_campatability_activated', $_POST['rs_discounts_compatability_module_checkbox']);
            } else {
                update_option('rs_discounts_campatability_activated', 'no');
            }
        }

        /**
         * Initialize the Default Settings by looping this function
         */
        public static function reward_system_default_settings() {
            global $woocommerce;
            foreach (RSDiscountsCompatability::reward_system_admin_fields() as $setting)
                if (isset($setting['newids']) && isset($setting['std'])) {
                    add_option($setting['newids'], $setting['std']);
                }
        }

        public static function rs_function_to_reset_discounts_campatability_tab() {
            $settings = RSDiscountsCompatability::reward_system_admin_fields();
            RSTabManagement::rs_function_to_reset_setting($settings);
        }

        public static function rs_function_to_enable_disable_discounts_campatability_module() {
            $get_option_value = get_option('rs_discounts_campatability_activated');
            $name_of_checkbox = 'rs_discounts_compatability_module_checkbox';
            RSModulesTab::rs_common_function_to_get_checkbox($get_option_value, $name_of_checkbox);
        }

    }

    RSDiscountsCompatability::init();
}
